@@ -202,7 +202,7 @@ namespace cuda {
       return sws.load_ram(img, tex.array) || sws.convert(frame->data[0], frame->data[1], frame->linesize[0], frame->linesize[1], tex_obj(tex), stream.get());
     }
 
-    int set_frame(AVFrame *frame, AVBufferRef *hw_frames_ctx) {
+    int set_frame(AVFrame *frame, AVBufferRef *hw_frames_ctx) override {
       if (cuda_t::set_frame(frame, hw_frames_ctx)) {
         return -1;
       }
@@ -929,7 +929,7 @@ namespace cuda {
         return platf::capture_e::ok;
       }
 
-      std::unique_ptr<platf::avcodec_encode_device_t> make_avcodec_encode_device(platf::pix_fmt_e pix_fmt) {
+      std::unique_ptr<platf::avcodec_encode_device_t> make_avcodec_encode_device(platf::pix_fmt_e pix_fmt) override {
         return ::cuda::make_avcodec_encode_device(width, height, true);
       }
 
